@@ -14,18 +14,20 @@ class CLayerRule {
         RULE_BLUR,
         RULE_BLURPOPUPS,
         RULE_DIMAROUND,
+        RULE_ABOVELOCK,
         RULE_IGNOREALPHA,
         RULE_IGNOREZERO,
         RULE_XRAY,
         RULE_ANIMATION,
         RULE_ORDER,
         RULE_ZUMBA,
+        RULE_NOSCREENSHARE
     };
 
-    eRuleType           ruleType = RULE_INVALID;
+    eRuleType           m_ruleType = RULE_INVALID;
 
-    const std::string   targetNamespace;
-    const std::string   rule;
+    const std::string   m_targetNamespace;
+    const std::string   m_rule;
 
-    CRuleRegexContainer targetNamespaceRegex;
-};
\ No newline at end of file
+    CRuleRegexContainer m_targetNamespaceRegex;
+};
